@@ -127,7 +127,7 @@ class Transcription(models.Model):
                     where = [UR_LOOKUP],
                     params = ['|'.join(patterns)])
         nd = len(neighs)
-        fwnd = sum([ x.getFreq() for x in neighs])
+        fwnd = sum([ x.get_frequency() for x in neighs])
         self.neigh_den = nd
         self.fwnd = fwnd
         self.save()
