@@ -1,5 +1,6 @@
 import os
 import re
+import math
 
 from celery import task,chord,group,chain
 from celery.signals import task_success
@@ -239,7 +240,7 @@ def loadTransWF(wfs):
 @task()
 def doStringSelect(form):
     qs = WordForm.objects.all()
-    qs = qs.filter(lemma__category__in = form['categories']).select_related('lemma','lemma__category').prefetch_related('orthographies','transcriptions')
+    qs = qs.filter(lemma__category__in = form['categories']).select_related('lemma','lemma__category').prefetch_related('orthographies','transcriptions','word')
     if form['exclude_punctuation']:
         qs = qs.exclude(orthographies__spelling__contains="'")
         qs = qs.exclude(orthographies__spelling__contains=".")
@@ -248,7 +249,7 @@ def doStringSelect(form):
     if form['exclude_titlecase']:
         qs = qs.exclude(orthographies__spelling__regex="^[A-Z]")
     qs = qs.filter(transcriptions__cvskel = form['cvskel'])
-    qs = qs.filter(frequency__gt = 1.0)
+    qs = qs.filter(frequency__gt = 1500.0)
     comps = []
     print len(qs)
     for i in range(len(qs)):
@@ -272,10 +273,10 @@ def analyze_block(comp):
     for c in comp:
         q = c[0]
         s = c[1]
-        t_one = str(q.transcriptions.all()[0]).encode('ascii')
-        o_one = [str(x) for x in q.orthographies.all()]
-        t_two = str(s.transcriptions.all()[0]).encode('ascii')
-        o_two = [str(x) for x in s.orthographies.all()]
+        t_one = str(q.transcriptions.all()[0])
+        o_one = q.orthographies.all()
+        t_two = str(s.transcriptions.all()[0])
+        o_two = s.orthographies.all()
         phon_dist = str(get_phone_dist(re.sub('\'','',t_one),re.sub('\'','',t_two)))
         #if not is_neighbour(re.sub('\'','',t_one),re.sub('\'','',t_two)):
         #    if t_one != t_two:
@@ -284,15 +285,15 @@ def analyze_block(comp):
         #else:
         #    phon_dist = "neighbour"
         in_context_entropy = str(in_trigram_context_entropy(o_one,o_two))
-        c_one = str(q.lemma.category.label).encode('ascii')
-        c_two = str(s.lemma.category.label).encode('ascii')
+        c_one = str(q.lemma.category.label)
+        c_two = str(s.lemma.category.label)
         f_one = str(q.frequency)
         f_two = str(s.frequency)
-        L_one = str(q.lemma.label).encode('ascii')
-        L_two = str(s.lemma.label).encode('ascii')
+        L_one = str(q.lemma.label)
+        L_two = str(s.lemma.label)
         LFreq_one = str(q.lemma.frequency)
         LFreq_two = str(s.lemma.frequency)
-        output.append([':'.join(o_one),':'.join(o_two),t_one,t_two,
+        output.append([':'.join(map(str,o_one)),':'.join(map(str,o_two)),t_one,t_two,
                                 c_one,c_two,f_one,f_two,L_one,L_two,
                                 LFreq_one,LFreq_two,phon_dist,in_context_entropy])
     return output
@@ -308,3 +309,39 @@ def combine_results(allout):
             for line in allout:
                 f.write("\t".join(line))
                 f.write("\n")
+
+def in_trigram_context_entropy(w_one,w_two):
+    w_one_contexts = {x.get_context(): x.count for x in w_one}
+    w_two_contexts = {x.get_context(): x.count for x in w_two}
+    w_one_contexts.update({x:0 for x in w_two_contexts if x not in w_one_contexts})
+    w_two_contexts.update({x:0 for x in w_one_contexts if x not in w_two_contexts})
+    #print(w_one_contexts)
+    #print(w_two_contexts)
+    #print w_one_contexts
+    #print w_two_contexts
+    c_w_one = sum([x.count for x in w_one])
+    c_w_two = sum([x.count for x in w_two])
+    #print(c_w_one)
+    #print(c_w_two)
+    context_ent = [entropy_calc(float(c_w_one),float(c_w_two),
+                                float(w_one_contexts[x]),float(w_two_contexts[x])) for x in w_one_contexts]
+    #print context_ent
+    #print(context_ent)
+    context_sum = sum(context_ent)
+    #print(context_sum)
+    return context_sum
+
+
+def entropy_calc(cntOne,cntTwo,cntCOne,cntCTwo):
+    #print cntOne
+    #print cntTwo
+    #print cntCOne
+    #print cntCTwo
+    pCGivenWords = (cntCOne + cntCTwo)/(cntOne + cntTwo)
+    Entp = cntCOne / (cntCOne + cntCTwo)
+    if Entp == 0.0:
+        Entp = 0.0000001
+    elif Entp == 1.0:
+        Entp = 0.9999999
+    HWordsGivenC = - (Entp * math.log(Entp)) - ((1-Entp) * math.log(1-Entp))
+    return pCGivenWords * HWordsGivenC
